pub type ConstArrayDeque<T, const N: usize> = ArrayDeque<T, ConstArrayLength<N>>;Expand description
ArrayDeque with a const-generic usize length, using the ConstArrayLength type alias for N.
To construct from a literal array, use from_array.
Note that not all N values are valid due to limitations inherent to typenum and Rust. You
may need to combine [Const] with other typenum operations to get the desired length.
Aliased Type
pub struct ConstArrayDeque<T, const N: usize> { /* private fields */ }